@@ -71,21 +71,6 @@ _Keywords=Network;Wireless;IP;LAN;Proxy;
 
 additionalfiles.generate(DOMAIN, PATH, "./panels/network/cinnamon-network-panel.desktop.in.in", prefix, _("Network"), _("Network settings"), "")
 
-prefix = """[Desktop Entry]
-Exec=cinnamon-control-center datetime
-Icon=cs-date-time
-Terminal=false
-Type=Application
-StartupNotify=true
-Categories=GTK;Settings;X-cinnamon-SystemSettings;X-Cinnamon-Settings-Panel;
-OnlyShowIn=X-Cinnamon;
-X-Cinnamon-Settings-Panel=datetime
-# Translators: those are keywords for the date and time control-center panel
-_Keywords=Clock;Timezone;Location;
-"""
-
-additionalfiles.generate(DOMAIN, PATH, "./panels/datetime/cinnamon-datetime-panel.desktop.in", prefix, _("Date & Time"), _("Date and Time preferences"), "")
-
 prefix = """[Desktop Entry]
 Exec=cinnamon-settings wacom
 Icon=cs-tablet
@@ -100,3 +85,17 @@ _Keywords=Tablet;Wacom;Stylus;Eraser;Mouse;
 """
 
 additionalfiles.generate(DOMAIN, PATH, "./panels/wacom/cinnamon-wacom-panel.desktop.in.in", prefix, _("Graphics Tablet"), _("Set button mappings and adjust stylus sensitivity for graphics tablets"), "")
+
+prefix = """[Desktop Entry]
+Exec=cinnamon-settings online-accounts
+Icon=cs-online-accounts
+Terminal=false
+Type=Application
+StartupNotify=true
+Categories=GTK;Settings;DesktopSettings;
+OnlyShowIn=X-Cinnamon;
+# Translators: those are keywords for the online-accounts control-center panel
+_Keywords=Google;Facebook;Twitter;Yahoo;Web;Online;Chat;Calendar;Mail;Contact;ownCloud;Kerberos;IMAP;SMTP;Pocket;ReadItLater;
+"""
+
+additionalfiles.generate(DOMAIN, PATH, "./panels/online-accounts/cinnamon-online-accounts-panel.desktop.in.in", prefix, _("Online Accounts"), _("Connect your online accounts"), "")
