@@ -22,16 +22,11 @@
 #include "config.h"
 
 #include <glib-object.h>
-#include <glib/gi18n-lib.h>
+#include <glib/gi18n.h>
 #include <arpa/inet.h>
 #include <netinet/ether.h>
 
-#include <nm-device-ethernet.h>
-#include <nm-device-modem.h>
-#include <nm-device-wifi.h>
-#include <nm-device-wimax.h>
-#include <nm-device-infiniband.h>
-#include <nm-utils.h>
+#include <NetworkManager.h>
 
 #include "net-device.h"
 
@@ -58,8 +53,6 @@ get_mac_address_of_connection (NMConnection *connection)
         if (!connection)
                 return NULL;
 
-        const GByteArray *mac = NULL;
-
         /* check the connection type */
         if (nm_connection_is_type (connection,
                                    NM_SETTING_WIRELESS_SETTING_NAME)) {
@@ -67,38 +60,14 @@ get_mac_address_of_connection (NMConnection *connection)
                 NMSettingWireless *s_wireless = nm_connection_get_setting_wireless (connection);
                 if (!s_wireless)
                         return NULL;
-                mac = nm_setting_wireless_get_mac_address (s_wireless);
-                if (mac)
-                        return nm_utils_hwaddr_ntoa (mac->data, ARPHRD_ETHER);
+                return g_strdup (nm_setting_wireless_get_mac_address (s_wireless));
         } else if (nm_connection_is_type (connection,
                                           NM_SETTING_WIRED_SETTING_NAME)) {
                 /* check wired settings */
                 NMSettingWired *s_wired = nm_connection_get_setting_wired (connection);
                 if (!s_wired)
                         return NULL;
-                mac = nm_setting_wired_get_mac_address (s_wired);
-                if (mac)
-                        return nm_utils_hwaddr_ntoa (mac->data, ARPHRD_ETHER);
-        } else if (nm_connection_is_type (connection,
-                                          NM_SETTING_WIMAX_SETTING_NAME)) {
-                /* check wimax settings */
-                NMSettingWimax *s_wimax = nm_connection_get_setting_wimax (connection);
-                if (!s_wimax)
-                        return NULL;
-                mac = nm_setting_wimax_get_mac_address (s_wimax);
-                if (mac)
-                        return nm_utils_hwaddr_ntoa (mac->data, ARPHRD_ETHER);
-        } else if (nm_connection_is_type (connection,
-                                          NM_SETTING_INFINIBAND_SETTING_NAME)) {
-                /* check infiniband settings */
-                NMSettingInfiniband *s_infiniband = \
-                        nm_connection_get_setting_infiniband (connection);
-                if (!s_infiniband)
-                        return NULL;
-                mac = nm_setting_infiniband_get_mac_address (s_infiniband);
-                if (mac)
-                        return nm_utils_hwaddr_ntoa (mac->data,
-                                                     ARPHRD_INFINIBAND);
+                return g_strdup (nm_setting_wired_get_mac_address (s_wired));
         }
         /* no MAC address found */
         return NULL;
@@ -122,19 +91,6 @@ get_mac_address_of_device (NMDevice *device)
                 mac = nm_device_ethernet_get_hw_address (device_ethernet);
                 break;
         }
-        case NM_DEVICE_TYPE_WIMAX:
-        {
-                NMDeviceWimax *device_wimax = NM_DEVICE_WIMAX (device);
-                mac = nm_device_wimax_get_hw_address (device_wimax);
-                break;
-        }
-        case NM_DEVICE_TYPE_INFINIBAND:
-        {
-                NMDeviceInfiniband *device_infiniband = \
-                        NM_DEVICE_INFINIBAND (device);
-                mac = nm_device_infiniband_get_hw_address (device_infiniband);
-                break;
-        }
         default:
                 break;
         }
@@ -171,15 +127,11 @@ net_device_real_get_find_connection (NetDevice *device)
         GSList *list, *iterator;
         NMConnection *connection = NULL;
         NMActiveConnection *ac;
-        NMRemoteSettings *remote_settings;
 
         /* is the device available in a active connection? */
-        remote_settings = net_object_get_remote_settings (NET_OBJECT (device));
         ac = nm_device_get_active_connection (device->priv->nm_device);
-        if (ac) {
-                return (NMConnection*)nm_remote_settings_get_connection_by_path (remote_settings,
-                                        nm_active_connection_get_connection (ac));
-        }
+        if (ac)
+                return (NMConnection*) nm_active_connection_get_connection (ac);
 
         /* not found in active connections - check all available connections */
         list = net_device_get_valid_connections (device);
@@ -227,6 +179,7 @@ state_changed_cb (NMDevice *device,
 NMDevice *
 net_device_get_nm_device (NetDevice *device)
 {
+        g_return_val_if_fail (NET_IS_DEVICE (device), NULL);
         return device->priv->nm_device;
 }
 
@@ -315,8 +268,7 @@ net_device_finalize (GObject *object)
                 g_signal_handler_disconnect (priv->nm_device,
                                              priv->changed_id);
         }
-        if (priv->nm_device != NULL)
-                g_object_unref (priv->nm_device);
+        g_clear_object (&priv->nm_device);
 
         G_OBJECT_CLASS (net_device_parent_class)->finalize (object);
 }
@@ -361,22 +313,24 @@ net_device_new (void)
 GSList *
 net_device_get_valid_connections (NetDevice *device)
 {
-        GSList *all, *filtered, *iterator, *valid;
+        GSList *valid;
         NMConnection *connection;
         NMSettingConnection *s_con;
         NMActiveConnection *active_connection;
         const char *active_uuid;
+        const GPtrArray *all;
+        GPtrArray *filtered;
+        guint i;
 
-        all = nm_remote_settings_list_connections (net_object_get_remote_settings (NET_OBJECT (device)));
+        all = nm_client_get_connections (net_object_get_client (NET_OBJECT (device)));
         filtered = nm_device_filter_connections (net_device_get_nm_device (device), all);
-        g_slist_free (all);
 
         active_connection = nm_device_get_active_connection (net_device_get_nm_device (device));
         active_uuid = active_connection ? nm_active_connection_get_uuid (active_connection) : NULL;
 
         valid = NULL;
-        for (iterator = filtered; iterator; iterator = iterator->next) {
-                connection = iterator->data;
+        for (i = 0; i < filtered->len; i++) {
+                connection = g_ptr_array_index (filtered, i);
                 s_con = nm_connection_get_setting_connection (connection);
                 if (!s_con)
                         continue;
@@ -387,7 +341,7 @@ net_device_get_valid_connections (NetDevice *device)
 
                 valid = g_slist_prepend (valid, connection);
         }
-        g_slist_free (filtered);
+        g_ptr_array_free (filtered, FALSE);
 
         return g_slist_reverse (valid);
 }
